@@ -16,12 +16,9 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id$ */
-
-
 /* for user-space streams */
-PHPAPI extern php_stream_ops php_stream_userspace_ops;
-PHPAPI extern php_stream_ops php_stream_userspace_dir_ops;
+PHPAPI extern const php_stream_ops php_stream_userspace_ops;
+PHPAPI extern const php_stream_ops php_stream_userspace_dir_ops;
 #define PHP_STREAM_IS_USERSPACE	&php_stream_userspace_ops
 #define PHP_STREAM_IS_USERSPACE_DIR	&php_stream_userspace_dir_ops
 
